@@ -15,47 +15,49 @@
 #include "metalinksettings.h"
 #include "metalinkxml.h"
 
-#include "core/kget.h"
-#include "core/transfergroup.h"
 #include "core/download.h"
-#include "core/transferdatasource.h"
 #include "core/filemodel.h"
+#include "core/kget.h"
+#include "core/signature.h"
+#include "core/transferdatasource.h"
+#include "core/transfergroup.h"
 #include "core/urlchecker.h"
 #include "core/verifier.h"
-#include "core/signature.h"
 
 #include "kget_debug.h"
 
-#include <kwidgetsaddons_version.h>
 #include <KIO/DeleteJob>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QDialog>
+#include <kwidgetsaddons_version.h>
 
-
-#include <QFile>
+#include <KConfigGroup>
 #include <QDir>
 #include <QDomElement>
+#include <QFile>
 #include <QStandardPaths>
-#include <KConfigGroup>
 
 /**
-* @return Hex value from a base64 value
-* @note needed for hex based signature verification
-*/
-QString base64ToHex(const QString& b64)
+ * @return Hex value from a base64 value
+ * @note needed for hex based signature verification
+ */
+QString base64ToHex(const QString &b64)
 {
-     return QString(QByteArray::fromBase64(b64.toLatin1()).toHex());
+    return QString(QByteArray::fromBase64(b64.toLatin1()).toHex());
 }
 
-MetalinkHttp::MetalinkHttp(TransferGroup * parent, TransferFactory * factory,
-                         Scheduler * scheduler, const QUrl & source, const QUrl & dest,
-                         KGetMetalink::MetalinkHttpParser *httpParser,
-                         const QDomElement * e)
-    : AbstractMetalink(parent,factory,scheduler,source, dest, e) ,
-      m_signatureUrl(QUrl()),
-      m_httpparser(httpParser)
+MetalinkHttp::MetalinkHttp(TransferGroup *parent,
+                           TransferFactory *factory,
+                           Scheduler *scheduler,
+                           const QUrl &source,
+                           const QUrl &dest,
+                           KGetMetalink::MetalinkHttpParser *httpParser,
+                           const QDomElement *e)
+    : AbstractMetalink(parent, factory, scheduler, source, dest, e)
+    , m_signatureUrl(QUrl())
+    , m_httpparser(httpParser)
 
 {
     m_httpparser->setParent(this);
@@ -63,14 +65,13 @@ MetalinkHttp::MetalinkHttp(TransferGroup * parent, TransferFactory * factory,
 
 MetalinkHttp::~MetalinkHttp()
 {
-
 }
 
 void MetalinkHttp::load(const QDomElement *element)
 {
     qCDebug(KGET_DEBUG);
     Transfer::load(element);
-    auto * fac = new DataSourceFactory(this, m_dest);
+    auto *fac = new DataSourceFactory(this, m_dest);
     m_dataSourceFactory.insert(m_dest, fac);
 
     connect(fac, &DataSourceFactory::capabilitiesChanged, this, &MetalinkHttp::slotUpdateCapabilities);
@@ -99,15 +100,12 @@ void MetalinkHttp::startMetalink()
 {
     if (m_ready) {
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
-            //specified number of files is downloaded simultaneously
+            // specified number of files is downloaded simultaneously
             if (m_currentFiles < MetalinkSettings::simultaneousFiles()) {
                 const Job::Status status = factory->status();
 
-                //only start factories that should be downloaded
-                if (factory->doDownload() &&
-                    (status != Job::Finished) &&
-                    (status != Job::FinishedKeepAlive) &&
-                    (status != Job::Running)) {
+                // only start factories that should be downloaded
+                if (factory->doDownload() && (status != Job::Finished) && (status != Job::FinishedKeepAlive) && (status != Job::Running)) {
                     ++m_currentFiles;
                     factory->start();
                 }
@@ -133,17 +131,16 @@ void MetalinkHttp::start()
     }
 }
 
-void MetalinkHttp::setSignature(QUrl & dest, QByteArray & data, DataSourceFactory* dataFactory)
+void MetalinkHttp::setSignature(QUrl &dest, QByteArray &data, DataSourceFactory *dataFactory)
 {
     Q_UNUSED(dest);
-    dataFactory->signature()->setSignature(data,Signature::AsciiDetached);
-
+    dataFactory->signature()->setSignature(data, Signature::AsciiDetached);
 }
 
 void MetalinkHttp::slotSignatureVerified()
 {
     if (status() == Job::Finished) {
-        //see if some files are NotVerified
+        // see if some files are NotVerified
         QStringList brokenFiles;
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
             if (m_fileModel) {
@@ -155,26 +152,25 @@ void MetalinkHttp::slotSignatureVerified()
             }
         }
 
-        if (brokenFiles.count())
-        {
+        if (brokenFiles.count()) {
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (KMessageBox::warningTwoActionsList(nullptr,
 #else
             if (KMessageBox::warningYesNoList(nullptr,
 #endif
-                    i18n("The download could not be verified, try to repair it?"),
-                    brokenFiles, QString(),
-                    KGuiItem(i18nc("@action:button", "Repair")),
-                    KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
+                                                   i18n("The download could not be verified, try to repair it?"),
+                                                   brokenFiles,
+                                                   QString(),
+                                                   KGuiItem(i18nc("@action:button", "Repair")),
+                                                   KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 == KMessageBox::PrimaryAction) {
 #else
                 == KMessageBox::Yes) {
 #endif
-                    if (repair()) {
+                if (repair()) {
                     KGet::addTransfer(m_metalinkxmlUrl);
-                    //TODO Use a Notification instead. Check kget.h for how to use it.
-
+                    // TODO Use a Notification instead. Check kget.h for how to use it.
                 }
             }
         }
@@ -188,10 +184,10 @@ bool MetalinkHttp::metalinkHttpInit()
     QUrl dest = QUrl(tempDest.toString() + m_dest.fileName());
     qDebug() << "dest = " << dest;
 
-    //sort the urls according to their priority (highest first)
+    // sort the urls according to their priority (highest first)
     std::stable_sort(m_linkheaderList.begin(), m_linkheaderList.end());
 
-    auto *dataFactory = new DataSourceFactory(this,dest);
+    auto *dataFactory = new DataSourceFactory(this, dest);
     dataFactory->setMaxMirrorsUsed(MetalinkSettings::mirrorsPerFile());
 
     connect(dataFactory, &DataSourceFactory::capabilitiesChanged, this, &MetalinkHttp::slotUpdateCapabilities);
@@ -200,16 +196,16 @@ bool MetalinkHttp::metalinkHttpInit()
     connect(dataFactory->signature(), SIGNAL(verified(int)), this, SLOT(slotSignatureVerified()));
     connect(dataFactory, &DataSourceFactory::log, this, &Transfer::setLog);
 
-    //add the Mirrors Sources
+    // add the Mirrors Sources
 
-    for(int i = 0; i < m_linkheaderList.size(); ++i) {
+    for (int i = 0; i < m_linkheaderList.size(); ++i) {
         const QUrl url = m_linkheaderList[i].url;
         if (url.isValid()) {
             if (m_linkheaderList[i].pref) {
-                qDebug() << "found etag in a mirror" ;
-                auto* eTagCher = new KGetMetalink::MetalinkHttpParser(url) ;
-                if (eTagCher->getEtag() != m_httpparser->getEtag()) { //There is an ETag mismatch
-                    continue ;
+                qDebug() << "found etag in a mirror";
+                auto *eTagCher = new KGetMetalink::MetalinkHttpParser(url);
+                if (eTagCher->getEtag() != m_httpparser->getEtag()) { // There is an ETag mismatch
+                    continue;
                 }
             }
 
@@ -217,20 +213,20 @@ bool MetalinkHttp::metalinkHttpInit()
         }
     }
 
-    //no datasource has been created, so remove the datasource factory
+    // no datasource has been created, so remove the datasource factory
     if (dataFactory->mirrors().isEmpty()) {
-        qDebug() << "data source factory being deleted" ;
+        qDebug() << "data source factory being deleted";
         delete dataFactory;
     } else {
         QHashIterator<QString, QString> itr(m_DigestList);
-        while(itr.hasNext()) {
+        while (itr.hasNext()) {
             itr.next();
-            qDebug() << itr.key() << ":" << itr.value() ;
+            qDebug() << itr.key() << ":" << itr.value();
         }
 
         dataFactory->verifier()->addChecksums(m_DigestList);
 
-        //Add OpenPGP signatures
+        // Add OpenPGP signatures
         if (m_signatureUrl != QUrl()) {
             // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
             if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation))) {
@@ -238,7 +234,7 @@ bool MetalinkHttp::metalinkHttpInit()
             }
             const QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/metalinks/") + m_source.fileName();
             auto *signat_download = new Download(m_signatureUrl, QUrl::fromLocalFile(path));
-            connect(signat_download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(setSignature(QUrl,QByteArray)));
+            connect(signat_download, SIGNAL(finishedSuccessfully(QUrl, QByteArray)), SLOT(setSignature(QUrl, QByteArray)));
         }
         m_dataSourceFactory[dataFactory->dest()] = dataFactory;
     }
@@ -248,7 +244,7 @@ bool MetalinkHttp::metalinkHttpInit()
     }
 
     if (!m_dataSourceFactory.size()) {
-        //TODO make this via log in the future + do not display the KMessageBox
+        // TODO make this via log in the future + do not display the KMessageBox
         qCWarning(KGET_DEBUG) << "Download of" << m_source << "failed, no working URLs were found.";
         KMessageBox::error(nullptr, i18n("Download failed, no working URLs were found."), i18n("Error"));
         setStatus(Job::Aborted);
@@ -264,7 +260,7 @@ bool MetalinkHttp::metalinkHttpInit()
 
 void MetalinkHttp::setLinks()
 {
-    const QMultiMap<QString, QString>* headerInf = m_httpparser->getHeaderInfo();
+    const QMultiMap<QString, QString> *headerInf = m_httpparser->getHeaderInfo();
     const QList<QString> linkVals = headerInf->values("link");
 
     foreach (const QString link, linkVals) {
@@ -272,12 +268,10 @@ void MetalinkHttp::setLinks()
 
         if (linkheader.reltype == "duplicate") {
             m_linkheaderList.append(linkheader);
-        }
-        else if (linkheader.reltype == "application/pgp-signature") {
-            m_signatureUrl = linkheader.url; //There will only be one signature
-        }
-        else if (linkheader.reltype == "application/metalink4+xml") {
-            m_metalinkxmlUrl = linkheader.url ; // There will only be one metalink xml (metainfo URL)
+        } else if (linkheader.reltype == "application/pgp-signature") {
+            m_signatureUrl = linkheader.url; // There will only be one signature
+        } else if (linkheader.reltype == "application/metalink4+xml") {
+            m_metalinkxmlUrl = linkheader.url; // There will only be one metalink xml (metainfo URL)
         }
     }
 }
@@ -293,32 +287,27 @@ void MetalinkHttp::deinit(Transfer::DeleteOptions options)
 
 void MetalinkHttp::setDigests()
 {
-    const QMultiMap<QString, QString>* digestInfo = m_httpparser->getHeaderInfo();
+    const QMultiMap<QString, QString> *digestInfo = m_httpparser->getHeaderInfo();
     const QList<QString> digestList = digestInfo->values("digest");
 
-    foreach(const QString digest, digestList) {
+    foreach (const QString digest, digestList) {
         const int eqDelimiter = digest.indexOf('=');
         const QString digestType = MetalinkHttp::adaptDigestType(digest.left(eqDelimiter).trimmed());
         const QString hexDigestValue = base64ToHex(digest.mid(eqDelimiter + 1).trimmed());
 
-        m_DigestList.insertMulti(digestType,hexDigestValue);
+        m_DigestList.insertMulti(digestType, hexDigestValue);
     }
 }
 
-QString MetalinkHttp::adaptDigestType(const QString & hashType)
+QString MetalinkHttp::adaptDigestType(const QString &hashType)
 {
     if (hashType == QString("SHA")) {
         return QString("sha");
-    }
-    else if (hashType == QString("MD5")) {
+    } else if (hashType == QString("MD5")) {
         return QString("md5");
-    }
-    else if (hashType == QString("SHA-256")) {
+    } else if (hashType == QString("SHA-256")) {
         return QString("sha256");
-    }
-    else {
+    } else {
         return hashType;
     }
 }
-
-
